@@ -651,8 +651,10 @@ listbox $LISTSCROL.list -yscroll  "$LISTSCROL.scroll set"
 #---------------------------
 $LISTSCROL.list  insert 0 \
 ant\
+ant3d\
 apollonian\
 atlantis\
+atunnels\
 ball\
 bat\
 blot\
@@ -755,6 +757,7 @@ swirl\
 t3d\
 tetris\
 text3d\
+text3d2\
 thornbird\
 tik_tak\
 triangle\
