@@ -75,8 +75,10 @@ add("North", Panel3);
 
 add("Center",lst);
 lst.addItem("ant");
+lst.addItem("ant3d");
 lst.addItem("apollonian");
 lst.addItem("atlantis");
+lst.addItem("atunnels");
 lst.addItem("ball");
 lst.addItem("bat");
 lst.addItem("blot");
@@ -179,6 +181,7 @@ lst.addItem("swirl");
 lst.addItem("t3d");
 lst.addItem("tetris");
 lst.addItem("text3d");
+lst.addItem("text3d2");
 lst.addItem("thornbird");
 lst.addItem("tik_tak");
 lst.addItem("triangle");
