@@ -696,7 +696,10 @@ init_apollonian(ModeInfo * mi)
 	cp->altgeom = cp->label && altgeom;
 
 	if (cp->quad == NULL) {
-		cp->count = ABS(MI_COUNT(mi));
+		if (MI_COUNT(mi))
+			cp->count = ABS(MI_COUNT(mi));
+		else
+			cp->count = 1;
 		if ((cp->quad = (apollonian_quadruple *) malloc(cp->count *
 			sizeof (apollonian_quadruple))) == NULL) {
 			return;
