@@ -376,7 +376,7 @@ free_bat(Display *display, bouncestruct *bp)
 {
 	free_stuff(display, bp);
 	if (bp->bats != NULL) {
-		(void) free((void *) bp->bats);
+		free(bp->bats);
 		bp->bats = (batstruct *) NULL;
 	}
 	if (bp->pixmap != None) {
@@ -526,7 +526,7 @@ init_bat(ModeInfo * mi)
 	if (bp->nbats < -MINBATS) {
 		/* if bp->nbats is random ... the size can change */
 		if (bp->bats != NULL) {
-			(void) free((void *) bp->bats);
+			free(bp->bats);
 			bp->bats = (batstruct *)NULL;
 		}
 		bp->nbats = NRAND(-bp->nbats - MINBATS + 1) + MINBATS;
@@ -681,7 +681,7 @@ release_bat(ModeInfo * mi)
 
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_bat(MI_DISPLAY(mi), &bounces[screen]);
-		(void) free((void *) bounces);
+		free(bounces);
 		bounces = (bouncestruct *) NULL;
 	}
 }
