@@ -444,7 +444,7 @@ bounce_windows(ModeInfo * mi, bouncestruct * bp)
 	}
 	bp->nwindow = nchildren;
 	if (bp->windows != NULL)
-		(void) free((void *) bp->windows);
+		free(bp->windows);
 	if ((bp->windows = (ballwindow *) malloc(bp->nwindow *
 			sizeof (ballwindow))) == NULL) {
 		XFree((caddr_t) children);
@@ -462,7 +462,7 @@ bounce_windows(ModeInfo * mi, bouncestruct * bp)
 		if (XGetWindowAttributes(MI_DISPLAY(mi), children[i], &att) == 0) {	/* failure */
 			XFree((caddr_t) children);
 			bp->nwindow = 0;
-			(void) free((void *) bp->windows);
+			free(bp->windows);
 			bp->windows = (ballwindow *) NULL;
 			return;
 		}
@@ -518,7 +518,7 @@ static void
 free_bounce(Display *display, bouncestruct *bp)
 {
 	if (bp->balls != NULL) {
-		(void) free((void *) bp->balls);
+		free(bp->balls);
 		bp->balls = (ballstruct *) NULL;
 	}
 	free_stuff(display, bp);
@@ -527,7 +527,7 @@ free_bounce(Display *display, bouncestruct *bp)
 		bp->stippledGC = None;
 	}
 	if (bp->windows != NULL) {
-		(void) free((void *) bp->windows);
+		free(bp->windows);
 		bp->windows = (ballwindow *) NULL;
 	}
 
@@ -609,7 +609,7 @@ init_bounce(ModeInfo * mi)
 	if (bp->nballs < -MINBALLS) {
 		/* if bp->nballs is random ... the size can change */
 		if (bp->balls != NULL) {
-			(void) free((void *) bp->balls);
+			free(bp->balls);
 			bp->balls = (ballstruct *) NULL;
 		}
 		bp->nballs = NRAND(-bp->nballs - MINBALLS + 1) + MINBALLS;
@@ -755,7 +755,7 @@ release_bounce(ModeInfo * mi)
 
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_bounce(MI_DISPLAY(mi), &bounces[screen]);
-		(void) free((void *) bounces);
+		free(bounces);
 		bounces = (bouncestruct *) NULL;
 	}
 }
