@@ -108,31 +108,15 @@ static const char sccsid[] = "@(#)dclock.c	5.00 2000/11/01 xlockmore";
 #ifndef METRIC
 #define METRIC 1
 #endif
+
 #if METRIC
-#ifdef NL
-# define AREA_STRING "Hectare"
-#else
-#ifdef JP
-# include "dclock-msg-jp.h"
-#else
-# define AREA_STRING "Hectares"
-#endif
-#endif
 #define AREA_MIN 35.303144
 #define AREA_TIME_START 1184193000.0
 #else
-#ifdef NL
-# define AREA_STRING "Acre"
-#else
-#ifdef JP
-# include "dclock-msg-jp.h"
-#else
-# define AREA_STRING "Acres"
-#endif
-#endif
 #define AREA_MIN 87.198766
 #define AREA_TIME_START 2924959000.0
 #endif
+
 #define PEOPLE_MIN 160.70344
 #define PEOPLE_TIME_START 3535369000.0
 #define HIV_MIN 10.6545
@@ -278,81 +262,15 @@ ModStruct   dclock_description =
 #endif
 #include <time.h>
 
-#ifdef FR
-#define POPEX_STRING "Population mondiale"
-#define PEOPLE_STRING " personnes"
-#define FOREST_STRING "Taille des forts tropicales"
-#define TROPICAL_STRING " zones tropicales en "
-#define HIV_STRING "Infections par le SIDA dans le monde"
-#define CASES_STRING " cas"
-#define LAB_STRING "Animaux utiliss dans la recherche"
-#define VEG_STRING "Animaux consomms comme aliments par l'homme"
-#define YEAR_STRING " cette anne"
-#define Y2K_STRING "Dcompte pour l'an 2000 (1er Janvier 2000)"
-#define POST_Y2K_STRING "Temps depuis l'an 2000 (1er Janvier 2000)"
-#define Y2001_STRING "Dcompte pour le Second Millnaire (1er Janvier 2001)"
-#define POST_Y2001_STRING "Temps depuis le Second Millnaire (1er Janvier 2001)"
-#define DAY "jour"
-#define DAYS "jours"
-#define HOUR "heure"
-#define HOURS "heures"
-#define MINUTE "minute"
-#define MINUTES "minutes"
-#define SECOND "seconde"
-#define SECONDS "secondes"
+/* language depended resources */
+#if defined FR
+#include "dclock-msg-fr.h"
+#elif defined NL
+#include "dclock-msg-nl.h"
+#elif defined JA
+#include "dclock-msg-ja.h"
 #else
-#ifdef NL
-#define POPEX_STRING "Wereld populatie"
-#define PEOPLE_STRING " Mensen"
-#define FOREST_STRING "Aantal tropische wouden"
-#define TROPICAL_STRING " Tropisch gebied in "
-#define HIV_STRING "Huidige staat HIV infecties wereldwijd"
-#define CASES_STRING " gevallen"
-#define LAB_STRING "Verbruikt tijdens onderzoek"
-#define VEG_STRING "Opgegeten door de mens"
-#define YEAR_STRING " dieren dit jaar"
-#define Y2K_STRING "Aftellen tot Y2K (1 Januari 2000, 0.00 uur)"
-#define POST_Y2K_STRING "Tijd sinds Y2K (1 Januari 2000)"
-#define Y2001_STRING "Aftellen tot het einde van het tweede Millennium (1 Januari 2001, 0.00 uur)"
-#define POST_Y2001_STRING "Verstreken tijd sinds het begin van het derde Millennium (1 Januari 2001)"
-
-#define Y2001_STRING "Aftellen tot het tweede millennium (1 Januari 2001)"
-#define POST_Y2001_STRING "Tijd sinds het tweede millennium (1 Januari 2001)"
-#define DAY "dag"
-#define DAYS "dagen"
-#define HOUR "uur"
-#define HOURS "uren"
-#define MINUTE "minuut"
-#define MINUTES "minuten"
-#define SECOND "seconde"
-#define SECONDS "seconden"
-#else
-#ifdef JP
-#include "dclock-msg-jp.h"
-#else
-#define POPEX_STRING "World Population"
-#define PEOPLE_STRING " People"
-#define FOREST_STRING "Tropical Forest Countdown"
-#define TROPICAL_STRING " Tropical Forest in "
-#define HIV_STRING "Current HIV Infections World Wide"
-#define CASES_STRING " Cases"
-#define LAB_STRING "Used in research"
-#define VEG_STRING "Consumed for Food by Mankind"
-#define YEAR_STRING " animals this year"
-#define Y2K_STRING "Countdown to Y2K (1 January 2000, 0:00 hour)"
-#define POST_Y2K_STRING "Time since Y2K (1 January 2000)"
-#define Y2001_STRING "Countdown to the end of the Second Millennium (1 January 2001, 0:00 hour)"
-#define POST_Y2001_STRING "Time since the start of the Third Millennium (1 January 2001)"
-#define DAY "day"
-#define DAYS "days"
-#define HOUR "hour"
-#define HOURS "hours"
-#define MINUTE "minute"
-#define MINUTES "minutes"
-#define SECOND "second"
-#define SECONDS "seconds"
-#endif
-#endif
+#include "dclock-msg-en.h"
 #endif
 
 #ifdef USE_MB
