@@ -151,7 +151,7 @@ ModStruct   dilemma_description =
 static XImage logo[BITMAPS] =
 {
     {0, 0, 0, XYBitmap, (char *) cooperat_bits, LSBFirst, 8, LSBFirst, 8, 1},
-      {0, 0, 0, XYBitmap, (char *) defect_bits, LSBFirst, 8, LSBFirst, 8, 1},
+    {0, 0, 0, XYBitmap, (char *) defect_bits, LSBFirst, 8, LSBFirst, 8, 1}
 };
 
 /* Dilemma data */
