@@ -213,7 +213,7 @@ init_discrete(ModeInfo * mi)
 		case AILUJ:
 			{
 				int         i;
-				double      x, y, xn, yn;
+				double      x, y, xtemp, ytemp;
 
 				hp->ic = 0;
 				hp->jc = 0;
@@ -225,10 +225,10 @@ init_discrete(ModeInfo * mi)
 					x = y = 0;
 #define MAXITER 10
 					for (i = 0; i < MAXITER && x * x + y * y < 13; i++) {	/* 'Brot calc */
-						xn = x * x - y * y + hp->a;
-						yn = 2 * x * y + hp->b;
-						x = xn;
-						y = yn;
+						xtemp = x * x - y * y + hp->a;
+						ytemp = 2 * x * y + hp->b;
+						x = xtemp;
+						y = ytemp;
 					}
 				} while (i < MAXITER);	/* wait for a connected set */
 				hp->i = hp->j = 0.1;
