@@ -874,7 +874,7 @@ freePairsOfEyes(Display * display, EyeScrInfo * ep)
 		for (en = 0; en < ep->num_eyes; en++)
 			if (ep->eyes[en].pixmap != None)
 				XFreePixmap(display, ep->eyes[en].pixmap);
-		(void) free((void *) ep->eyes);
+		free(ep->eyes);
 		ep->eyes = (Eyes *) NULL;
 	}
 }
@@ -1077,7 +1077,7 @@ release_eyes(ModeInfo * mi)
 
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_eyes(MI_DISPLAY(mi), &eye_info[screen]);
-		(void) free((void *) eye_info);
+		free(eye_info);
 	}
 	eye_info = (EyeScrInfo *) NULL;
 }
