@@ -250,7 +250,7 @@ normalize(GLfloat v[3])
 #endif
 
 /* Set up and enable texturing on our object */
-static void
+static Bool
 setup_xbm_texture (unsigned char *bits, int width, int height,
 				   XColor *fgc, XColor *bgc)
 {
@@ -280,7 +280,12 @@ setup_xbm_texture (unsigned char *bits, int width, int height,
   clear_gl_error();
   glTexImage2D(GL_TEXTURE_2D, 0, 3, width, height, 0,
 			   GL_RGB, GL_UNSIGNED_BYTE, data);
-  check_gl_error("texture");
+  if (check_gl_error("texture")) {
+	if (data != NULL) {
+		free(data);
+	}
+	return False;
+  }
 
   /* setup parameters for texturing */
   glPixelStorei(GL_UNPACK_ALIGNMENT, 1);
@@ -293,10 +298,11 @@ setup_xbm_texture (unsigned char *bits, int width, int height,
   if (data != NULL) {
 	free(data);
   }
+	return True;
 }
 
 
-static void
+static Bool
 setup_file_texture (ModeInfo *mi, char *filename)
 {
 #ifdef HAVE_XPM
@@ -309,11 +315,13 @@ setup_file_texture (ModeInfo *mi, char *filename)
 		XImage *image = xpm_to_ximage (MI_DISPLAY(mi), MI_VISUAL(mi),
 			 MI_COLORMAP(mi), xpm_data);
 
-        clear_gl_error();
+		clear_gl_error();
 		glTexImage2D(GL_TEXTURE_2D, 0, GL_RGBA,
 					 image->width, image->height, 0,
 					 GL_RGBA, GL_UNSIGNED_BYTE, image->data);
-        check_gl_error("texture");
+		if (check_gl_error("texture A")) {
+			return False;
+		}
 
 		/* setup parameters for texturing */
 		glPixelStorei(GL_UNPACK_ALIGNMENT, 4);
@@ -324,14 +332,13 @@ setup_file_texture (ModeInfo *mi, char *filename)
 		glTexParameterf(GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, GL_REPEAT);
 		glTexParameterf(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);
 		glTexParameterf(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
-		return;
+		return True;
 	  }
 	  break;
 
 	case XpmOpenFailed:
 	  (void) fprintf (stderr, "Glplanet: file %s doesn't exist.\n", filename);
-	  exit (-1);
-	  break;
+	  return False;
 
 	case XpmFileInvalid:
 	  /* Fall through and try it as an XBM. */
@@ -339,13 +346,11 @@ setup_file_texture (ModeInfo *mi, char *filename)
 
 	case XpmNoMemory:
 	  (void) fprintf (stderr, "Glplanet: XPM: out of memory\n");
-	  exit (-1);
-	  break;
+	  return False;
 
 	default:
 	  (void) fprintf (stderr, "Glplanet: XPM: unknown error code %d\n", result);
-	  exit (-1);
-	  break;
+	  return False;
 	}
   }
 #endif /* HAVE_XPM */
@@ -365,11 +370,14 @@ setup_file_texture (ModeInfo *mi, char *filename)
 		(void) fprintf (stderr, "Glplanet: not an XPM file: %s\n", filename);
 # endif
 		(void) fprintf (stderr, "Glplanet: not an XBM file: %s\n", filename);
-		exit (1);
+		return False;
 	  }
 
-	setup_xbm_texture ((unsigned char *) data, width, height, &gp->fg, &gp->bg);
+	if (!setup_xbm_texture ((unsigned char *) data, width, height,
+			&gp->fg, &gp->bg))
+		return False;
   }
+  return True;
 #else  /* !XMU */
 
 #ifdef HAVE_XPM
@@ -377,23 +385,27 @@ setup_file_texture (ModeInfo *mi, char *filename)
 # endif
   (void) fprintf (stderr, "Glplanet: your vendor doesn't ship the standard Xmu library.\n");
   (void) fprintf (stderr, "Glplanet: we can't load XBM files without it.\n");
-  exit (1);
+  return False;
 #endif /* !XMU */
 }
 
 
-static void
+static Bool
 setup_texture(ModeInfo * mi)
 {
   planetstruct *gp = &planets[MI_SCREEN(mi)];
   if (!which_image ||
 	  !*which_image ||
-	  !strcmp(which_image, "BUILTIN"))
-	setup_xbm_texture (earth_bits, earth_width, earth_height,
-					   &gp->fg, &gp->bg);
+	  !strcmp(which_image, "BUILTIN")) {
+	if (!setup_xbm_texture (earth_bits, earth_width, earth_height,
+					   &gp->fg, &gp->bg))
+		return False;
 
-  else
-	setup_file_texture (mi, which_image);
+  } else {
+	if (!setup_file_texture (mi, which_image))
+		return False;
+  }
+  return True;
 }
 
 
@@ -481,8 +493,10 @@ pinit(ModeInfo * mi)
   }
 
   /* turn on various options we like */
-  if (do_texture)
-	setup_texture(mi);
+  if (do_texture) {
+	if (!setup_texture(mi)) 
+		do_texture = False;
+  }
   if (do_light)
 	setup_light();
 
