@@ -173,7 +173,6 @@ ModStruct   skewb_description =
 #define RIGHT 9
 #define BOTTOM 10
 #define LEFT 11
-#define MAXORIENT 4
 #define MAXROTATE 3
 #define MAXCUBES (MAXORIENT+1)
 #define MINOR 0
@@ -682,12 +681,16 @@ draw_stickerless_cubit(skewbstruct * sp)
 	glVertex3f(CUBELEN, CUBEROUND, -CUBELEN);
 	glVertex3f(CUBEROUND, CUBEROUND, -CUBELEN);
 	glVertex3f(CUBEROUND, CUBELEN, -CUBELEN);
+	glEnd();
 
-	/* Invisible portion of cubit (FIX: not flush) */
+	glBegin(GL_POLYGON);
 	glNormal3f(-1.00, 1.00, 1.00);
-	glVertex3f(-CUBELEN, CUBEROUND, CUBEROUND);
-	glVertex3f(CUBEROUND, CUBEROUND, -CUBELEN);
-	glVertex3f(CUBEROUND, -CUBELEN, CUBEROUND);
+	glVertex3f(-CUBEROUND, CUBEROUND,  CUBELEN);
+	glVertex3f(-CUBEROUND, CUBELEN,  CUBEROUND);
+	glVertex3f(CUBEROUND, CUBELEN, -CUBEROUND);
+	glVertex3f(CUBELEN, CUBEROUND, -CUBEROUND);
+	glVertex3f(CUBELEN, -CUBEROUND, CUBEROUND);
+	glVertex3f(CUBEROUND, -CUBEROUND, CUBELEN);
 	glEnd();
 	return True;
 }
@@ -1002,8 +1005,8 @@ draw_cube(ModeInfo * mi)
 			glPushMatrix();
 			glTranslatef(-0.5, 0.5, -0.5);
 			glPushMatrix();
-			glRotatef(90.0, 0, 1, 0);
-			glRotatef(90.0, -1, 0, 0);
+			glRotatef(90.0, 0, -1, 0);
+			glRotatef(90.0, 0, 0, 1);
 			DRAW_STICKERLESS_CUBIT(sp);
 			glPopMatrix();
 			draw_cubit(mi, 0, 6, 2, 6, 6, 5);
