@@ -185,7 +185,7 @@ trig(ModeInfo * mi)
 	Display    *display = MI_DISPLAY(mi);
 	GC          gc = MI_GC(mi);
 	helixstruct *hp = &helixes[MI_SCREEN(mi)];
-	int         x1, y1, x2, y2;
+	int         x_1, y_1, x_2, y_2;
 	int         tmp, angle;
 
 
@@ -193,15 +193,15 @@ trig(ModeInfo * mi)
 
 	while (ABS(hp->d_angle) <= ANGLES) {
 		angle = hp->d_angle + hp->d_angle_offset;
-		x1 = (int) (sin_array[pmod(angle * hp->factor1, ANGLES)] * hp->xmid) +
+		x_1 = (int) (sin_array[pmod(angle * hp->factor1, ANGLES)] * hp->xmid) +
 			hp->xmid;
-		y1 = (int) (cos_array[pmod(angle * hp->factor1, ANGLES)] * hp->ymid) +
+		y_1 = (int) (cos_array[pmod(angle * hp->factor1, ANGLES)] * hp->ymid) +
 			hp->ymid;
-		x2 = (int) (sin_array[pmod(angle * hp->factor2 + hp->offset, ANGLES)] *
+		x_2 = (int) (sin_array[pmod(angle * hp->factor2 + hp->offset, ANGLES)] *
 			    hp->xmid) + hp->xmid;
-		y2 = (int) (cos_array[pmod(angle * hp->factor2 + hp->offset, ANGLES)] *
+		y_2 = (int) (cos_array[pmod(angle * hp->factor2 + hp->offset, ANGLES)] *
 			    hp->ymid) + hp->ymid;
-		XDrawLine(display, MI_WINDOW(mi), gc, x1, y1, x2, y2);
+		XDrawLine(display, MI_WINDOW(mi), gc, x_1, y_1, x_2, y_2);
 		if (MI_NPIXELS(mi) > 2) {
 			XSetForeground(display, gc, MI_PIXEL(mi, hp->color));
 			if (++hp->color >= MI_NPIXELS(mi))
