@@ -381,7 +381,8 @@ init_hop(ModeInfo * mi)
 	if (MI_NPIXELS(mi) > 2)
 		hp->pix = NRAND(MI_NPIXELS(mi));
 	hp->bufsize = MI_COUNT(mi);
-
+	if (hp->bufsize < 1)
+		hp->bufsize = 1;
 	if (hp->pointBuffer == NULL) {
 		if ((hp->pointBuffer = (XPoint *) malloc(hp->bufsize *
 				sizeof (XPoint))) == NULL)
