@@ -1119,7 +1119,7 @@ release_ico(ModeInfo * mi)
 
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_ico(MI_DISPLAY(mi), &icos[screen]);
-		(void) free((void *) icos);
+		free(icos);
 		icos = (icostruct *) NULL;
 	}
 }
