@@ -124,10 +124,10 @@ so the answer is to do a single 661 and then drop straight down to (5).
 #define DEF_TAIL "0" /* No trace */
 #ifdef UNI
 /* Maybe a ROLA BOLA would be at a better angle for viewing */
-#define DEF_UNI "FALSE" /* No unicycle */ /* Not implemented yet */
+#define DEF_UNI "False" /* No unicycle */ /* Not implemented yet */
 #endif
-#define DEF_REAL "TRUE"
-#define DEF_SOLID "FALSE" /* Not solid */
+#define DEF_REAL "True"
+#define DEF_SOLID "False" /* Not solid */
 
 static char *pattern;
 static int tail;
