@@ -68,7 +68,7 @@ static const char sccsid[] = "@(#)life1d.c	5.00 2000/11/01 xlockmore";
 
 #ifdef MODE_life1d
 
-#define DEF_TOTALISTIC  "True"	/* FALSE is LCAU */
+#define DEF_TOTALISTIC  "True"	/* False is LCAU */
 
 static Bool totalistic;
 
