@@ -78,7 +78,7 @@ ModStruct   munch_description =
 
 #endif
 
-#if DEBUG
+#ifdef DEBUG
 #include <assert.h>
 #endif
 
@@ -129,7 +129,7 @@ munchBit(ModeInfo * mi, int width,	/* pixels */
 		   while that might be a pretty feature, I didn't want it to do
 		   that yet.  if these trigger, please let me know.
 		 */
-#if DEBUG
+#ifdef DEBUG
 		assert(drawX >= 0 && drawX < MI_WIDTH(mi));
 		assert(drawY >= 0 && drawY < MI_HEIGHT(mi));
 #endif
