@@ -241,7 +241,7 @@ init_qix(ModeInfo * mi)
 		qp->nlines = qp->npoints;
 	}
 	if (qp->kaleid) {
-		qp->nlines = MI_CYCLES(mi) * 16;	/* Fudge it so its compatible */
+		qp->nlines = (MI_CYCLES(mi) + 1) * 8;	/* Fudge it so its compatible */
 	}
 	if (qp->lineq) {
 		free(qp->lineq);
