@@ -312,7 +312,8 @@ void init_scooter(ModeInfo *mi)
 	sp->doorcount = MAX(MI_COUNT(mi),MIN_DOORS);
 	sp->speed = MI_CYCLES(mi);
 	sp->starcount = MI_SIZE(mi);
-
+	if (sp->starcount < 1)
+		sp->starcount = 1;
 	if (sp->speed < MIN_SPEED)
 		sp->speed = MIN_SPEED;
 	if (sp->speed > MAX_SPEED)
