@@ -1385,7 +1385,7 @@ release_solitare(ModeInfo * mi)
 			if (bp->game)
 				delete bp->game;
 		}
-		(void) free((void *) solitare);
+		free(solitare);
 		solitare = (solitarestruct *) NULL;
 	}
 }
