@@ -2090,7 +2090,7 @@ refresh_tetris(ModeInfo * mi)
     for (col = 0; col < tp->ncols; col++)
       for (row = 0; row < tp->nrows; row++) {
         pos = row * tp->ncols + col;
-#if DEBUG 
+#ifdef DEBUG 
         (void) printf("pmid %d, cid %d, %d %d\n",
           tp->field[pos].pmid, tp->field[pos].cid, col, row);
 #endif
