@@ -183,8 +183,13 @@ draw_thornbird(ModeInfo * mi)
 	if (hp->pointBuffer == NULL)
 		return;
 
-	erase = (hp->inc + 1) % MI_CYCLES(mi);
-	current = hp->inc % MI_CYCLES(mi);
+	if (MI_CYCLES(mi) < 1) {
+		current = 0;
+		erase = 0;
+	} else {
+		erase = (hp->inc + 1) % MI_CYCLES(mi);
+		current = hp->inc % MI_CYCLES(mi);
+	}
 	k = batchcount;
 
 
@@ -192,9 +197,9 @@ draw_thornbird(ModeInfo * mi)
 
 	/* vary papameters */
 	hp->a = 1.99 + (0.4 * sin(hp->inc / hp->liss.f1) +
-					0.05 * cos(hp->inc / hp->liss.f2));
+		0.05 * cos(hp->inc / hp->liss.f2));
 	hp->c = 0.80 + (0.15 * cos(hp->inc / hp->liss.f1) +
-					0.05 * sin(hp->inc / hp->liss.f2));
+			0.05 * sin(hp->inc / hp->liss.f2));
 
 	/* vary view */
 	hp->tumble.theta += hp->tumble.dtheta;
