@@ -100,8 +100,8 @@ ModStruct   tik_tak_description =
 typedef struct {
 	unsigned long colour;
         Bool        inner;
-	float       angle, velocity_a , angle1 , velocity_a1;
-   float size_mult , size_mult1;
+	float       angle, velocity_a, angle1, velocity_a1;
+	float       size_mult, size_mult1;
 	int         num_point, size_ob;
 	int         num_point1, size_ob1;
 	XPoint      *xy , *xy1;
@@ -109,7 +109,7 @@ typedef struct {
 
 typedef struct {
 	Bool        painted;
-	int         win_width, win_height, num_object , x0 , y0;
+	int         win_width, win_height, num_object, x0, y0;
 	tik_takobject *object;
 	GC          gc;
 	Colormap    cmap;
@@ -127,7 +127,7 @@ static void
 tik_tak_setupobject( ModeInfo * mi , tik_takobject * object0)
 {
 	tik_takstruct *tiktak = &tik_taks[MI_SCREEN(mi)];
-	int         x0=tiktak->x0 , y0=tiktak->y0 , i;
+	int         x_0=tiktak->x0 , y_0=tiktak->y0 , i;
    float curangle;
 
    for (i = 0; i <= object0->num_point; i++)
@@ -141,10 +141,10 @@ tik_tak_setupobject( ModeInfo * mi , tik_takobject * object0)
 	object0->size_mult = 1.0 / object0->size_mult;
 	curangle = object0->angle + i * 360.0 * PI_RAD /
 	  (float) object0->num_point;
-	object0->xy[i+object0->num_point+1].x = x0 +
+	object0->xy[i+object0->num_point+1].x = x_0 +
 	  (int) (object0->size_ob * cos(curangle)) +
 	  (int) (object0->size_ob * sin(curangle));
-	object0->xy[i+object0->num_point+1].y = y0 +
+	object0->xy[i+object0->num_point+1].y = y_0 +
 	  (int) (object0->size_ob * cos(curangle)) -
 	  (int) (object0->size_ob * sin(curangle));
      }
@@ -165,10 +165,10 @@ tik_tak_setupobject( ModeInfo * mi , tik_takobject * object0)
 	     object0->size_mult1 = 1.0 / object0->size_mult1;
 	     curangle = object0->angle1 + i * 360.0 * PI_RAD /
 	       (float) object0->num_point1;
-	     object0->xy1[i+object0->num_point1+1].x = x0 +
+	     object0->xy1[i+object0->num_point1+1].x = x_0 +
 	       (int) (object0->size_ob1 * cos(curangle)) +
 	       (int) (object0->size_ob1 * sin(curangle));
-	     object0->xy1[i+object0->num_point1+1].y = y0 +
+	     object0->xy1[i+object0->num_point1+1].y = y_0 +
 	       (int) (object0->size_ob1 * cos(curangle)) -
 	       (int) (object0->size_ob1 * sin(curangle));
 	  }
