@@ -86,7 +86,7 @@ ModStruct   triangle_description =
 #define MAX_LEVELS 1000
 
 #define DELTA  0.4
-#define LEFT   (-0.25)
+#define LEFT   -0.25
 #define RIGHT  1.25
 #define TOP    0.3
 #define BOTTOM 1.0
@@ -146,13 +146,15 @@ draw_atriangle(ModeInfo * mi, XPoint * p, int y_0, int y_1, int y_2, double dinv
 
 		XSetForeground(display, gc, MI_PIXEL(mi, color % MI_NPIXELS(mi)));
 		if (tp->joke) {
-			if ((Bool) (LRAND() & 1))
+			if ((Bool) (LRAND() & 1)) {
 				XDrawLines(display, window, gc, p, 4, CoordModeOrigin);
-			else
+			} else {
 				XFillPolygon(display, window, gc, p, 3, Convex, CoordModeOrigin);
+			}
 		} else if (tp->wireframe) {
 			XDrawLines(display, window, gc, p, 4, CoordModeOrigin);
 		} else {
+			/* dieing on my Sun here with gcc -g -O2, flakey */
 			XFillPolygon(display, window, gc, p, 3, Convex, CoordModeOrigin);
 		}
 	} else {
@@ -201,7 +203,7 @@ calc_points2(trianglestruct * tp, int d, int *y0_p, int *y1_p, int *y2_p, XPoint
 	p[1].y = tp->ypos[tp->j + d] - *y1_p;
 	p[2].y = tp->ypos[tp->j + d] - *y2_p;
 
-	p[3] = p[0];
+	p[3]= p[0];
 }
 
 
@@ -215,7 +217,7 @@ draw_mesh(ModeInfo * mi, trianglestruct * tp, int d, int count)
 	double      dinv = 0.2 / d;
 
 	if ((tp->j == 0) && (tp->i == 0)) {
-		MI_CLEARWINDOW(mi);
+		MI_CLEARWINDOWCOLORMAPFAST(mi, MI_GC(mi), MI_BLACK_PIXEL(mi));
 	}
 	for (; (tp->j < tp->size) && (count > 0); tp->j += ((count) ? d : 0)) {
 		for (tp->i = (first) ? tp->i : 0, first = 0;
