@@ -6,7 +6,7 @@
  * See xlock.c for copying information.
  *
  * Revision History:
- * Nov-99: updates by Eric Lassauge <lassauge@mail.dotcom.fr>:
+ * Nov-99: updates by Eric Lassauge <lassauge AT users.sourceforge.net>
  *         - Callbacks for 'Cancel' buttons , don't SIGSEGV anymore
  *         - FontSelection dialog updates for GTK 1.2.6
  *         - Drawing of little colored rectangle simplified, now works in
@@ -14,8 +14,8 @@
  *         - Add 'About' box
  *         - Add handling of "similar to xmlock" RC file
  *         - etc...
- * Jul-98: Continual improvements by Remi Cohen-Scali <remi.cohenscali@pobox.com>
- * ?? -98: First written by Charles Vidal <vidalc@club-internet.fr>.
+ * Jul-98: Continual improvements by Remi Cohen-Scali <remi.cohenscali AT pobox.com>
+ * ?? -98: First written by Charles Vidal <vidalc AT club-internet.fr>.
  */
 
 /*-
@@ -1079,7 +1079,7 @@ about_dialog(GtkWidget *w,
   gtk_box_pack_start(GTK_BOX(xvbox), xhbox, TRUE, TRUE, 0);
   text = "\nFirst written by Charles Vidal <vidalc@club-internet.fr>.\n"
          "Continual improvements by Remi Cohen-Scali <remi.cohenscali@pobox.com>.\n"
-         "Updates by Eric Lassauge <lassauge@mail.dotcom.fr>.\n\n"
+         "Updates by Eric Lassauge <lassauge@users.sourceforge.net>.\n\n"
          "GTK+ launcher for xlockmore: the maintained version of xlock.\n"
  	 "http://www.tux.org/~bagleyd/xlockmore.html\n"
 	 "Version 2.0\n";
