@@ -979,7 +979,7 @@ static int  currentEraseMode = -1;
 /* static int  previousEraseMode = -1; */
 static int *eraseModes;
 static int  nEraseModes;
-#if DEBUG
+#ifdef DEBUG
 static Bool sequential = True;
 #else
 static Bool sequential = False;
