@@ -1,5 +1,5 @@
 #if !defined( lint ) && !defined( SABER )
-static const char sccsid[] = "@(#)mode.c	4.07 97/11/24 xlockmore";
+static const char sccsid[] = "@(#)mode.c	5.12 04/03/09 xlockmore";
 
 #endif
 /*-
@@ -39,6 +39,12 @@ LockStruct  LockProcs[] =
 	 1000, -3, 40000, -12, 64, 1.0, (char *) "",
 	 (char *) "Shows Langton's and Turk's generalized ants", 0, NULL},
 #endif
+#ifdef MODE_ant3d
+	{(char *) "ant3d", init_ant3d, draw_ant3d, release_ant3d,
+	 refresh_ant3d, init_ant3d, (ModeHook *) NULL, &ant3d_opts,
+	 5000, -3, 100000, 1, 64, 1.0, (char *) "",
+	 (char *) "Shows 3D ants", 0, NULL},
+#endif
 #ifdef MODE_apollonian
 	{(char *) "apollonian", init_apollonian, draw_apollonian, release_apollonian,
 	 init_apollonian, init_apollonian, (ModeHook *) NULL, &apollonian_opts,
@@ -689,7 +695,13 @@ LockStruct  LockProcs[] =
 #ifdef MODE_text3d
 	{(char *) "text3d", init_text3d, draw_text3d, release_text3d,
 	 refresh_text3d, change_text3d, (ModeHook *) NULL, &text3d_opts,
-	 100000, 1, 1, 1, 64, 1.0, (char *) "",
+	 100000, 10, 1, 1, 64, 1.0, (char *) "",
+	 (char *) "Shows 3D text", 0, NULL},
+#endif
+#ifdef MODE_text3d2
+	{(char *) "text3d2", init_text3d2, draw_text3d2, release_text3d2,
+	 refresh_text3d2, change_text3d2, (ModeHook *) NULL, &text3d2_opts,
+	 100000, 10, 1, 1, 64, 1.0, (char *) "",
 	 (char *) "Shows 3D text", 0, NULL},
 #endif
 #ifdef MODE_thornbird
