@@ -346,6 +346,7 @@ static XrmOptionDescRec genTable[] =
 	{(char *) "+description", (char *) ".description", XrmoptionNoArg, (caddr_t) "off"},
 	{(char *) "-echokeys", (char *) ".echokeys", XrmoptionNoArg, (caddr_t) "on"},
 	{(char *) "+echokeys", (char *) ".echokeys", XrmoptionNoArg, (caddr_t) "off"},
+	{(char *) "-echokey", (char *) ".echokey", XrmoptionSepArg, (caddr_t) NULL},
 	{(char *) "-enablesaver", (char *) ".enablesaver", XrmoptionNoArg, (caddr_t) "on"},
 	{(char *) "+enablesaver", (char *) ".enablesaver", XrmoptionNoArg, (caddr_t) "off"},
 	{(char *) "-resetsaver", (char *) ".resetsaver", XrmoptionNoArg, (caddr_t) "on"},
@@ -577,6 +578,7 @@ static OptionStruct opDesc[] =
 	{(char *) "-/+debug", (char *) "whether to use debug xlock (yes/no)"},
 	{(char *) "-/+description", (char *) "whether to show mode description (yes/no)"},
 	{(char *) "-/+echokeys", (char *) "turn on/off echo '?' for each password key"},
+	{(char *) "-echokey char", (char *) "text character to use for echo key, default is '?'"},
 	{(char *) "-/+enablesaver", (char *) "turn on/off enable X server screen saver"},
 	{(char *) "-/+resetsaver", (char *) "turn on/off resetting of X server screen saver"},
 	{(char *) "-/+grabmouse", (char *) "turn on/off grabbing of mouse and keyboard"},
@@ -711,6 +713,7 @@ Bool        allowroot;
 Bool        debug;
 Bool        description;
 Bool        echokeys;
+char*       echokey;
 Bool        enablesaver;
 Bool        resetsaver;
 Bool        fullrandom = False;
@@ -851,6 +854,7 @@ static argtype genvars[] =
 	{(caddr_t *) & debug, (char *) "debug", (char *) "Debug", (char *) "off", t_Bool},
 	{(caddr_t *) & description, (char *) "description", (char *) "Description", (char *) "on", t_Bool},
 	{(caddr_t *) & echokeys, (char *) "echokeys", (char *) "EchoKeys", (char *) "off", t_Bool},
+	{(caddr_t *) & echokey, (char *) "echokey", (char *) "EchoKey", (char *) "?", t_String},
     {(caddr_t *) & enablesaver, (char *) "enablesaver", (char *) "EnableSaver", (char *) "off", t_Bool},
 	{(caddr_t *) & resetsaver, (char *) "resetsaver", (char *) "ResetSaver", (char *) "on", t_Bool},
 	{(caddr_t *) & grabmouse, (char *) "grabmouse", (char *) "GrabMouse", (char *) "on", t_Bool},
