@@ -2,7 +2,7 @@
  *                                                                         *
  * Author : Jouk Jansen (joukj@hrem.stm.tudelft.nl)                        *
  *                                                                         *
- * Last revision : 29 November 2002                                        *
+ * Last revision : 26 March 2004                                           *
  *                                                                         *
  * Repair definitions of Runtime library functions when compiling with     *
  * /name=(as_is) on OpenVMS                                                *
@@ -13,6 +13,7 @@
 #define VMS_X_FIX
 
 #define DtSaverGetWindows DTSAVERGETWINDOWS
+#define XAddExtension XADDEXTENSION
 #define XAddHosts XADDHOSTS
 #define XAllocClassHint XALLOCCLASSHINT
 #define XAllocColor XALLOCCOLOR
@@ -38,6 +39,7 @@
 #define XChangeWindowAttributes XCHANGEWINDOWATTRIBUTES
 #define XCheckIfEvent XCHECKIFEVENT
 #define XCheckMaskEvent XCHECKMASKEVENT
+#define XCheckTypedEvent XCHECKTYPEDEVENT
 #define XCheckTypedWindowEvent XCHECKTYPEDWINDOWEVENT
 #define XCheckWindowEvent XCHECKWINDOWEVENT
 #define XClearArea XCLEARAREA
@@ -56,6 +58,7 @@
 #define XCreateFontCursor XCREATEFONTCURSOR
 #define XCreateFontSet XCREATEFONTSET
 #define XCreateGC XCREATEGC
+#define XCreateGlyphCursor XCREATEGLYPHCURSOR
 #define XCreateIC XCREATEIC
 #define XCreateImage XCREATEIMAGE
 #define XCreatePixmap XCREATEPIXMAP
@@ -81,6 +84,7 @@
 #define XDisableAccessControl XDISABLEACCESSCONTROL
 #define XDisplayCells XDISPLAYCELLS
 #define XDisplayHeight XDISPLAYHEIGHT
+#define XDisplayKeycodes XDISPLAYKEYCODES
 #define XDisplayName XDISPLAYNAME
 #define XDisplayOfScreen XDISPLAYOFSCREEN
 #define XDisplayWidth XDISPLAYWIDTH
@@ -99,11 +103,14 @@
 #define XDrawString16 XDRAWSTRING16
 #define XDrawText XDRAWTEXT
 #define XDrawText16 XDRAWTEXT16
+#define XESetCloseDisplay XESETCLOSEDISPLAY
 #define XEmptyRegion XEMPTYREGION
 #define XEnableAccessControl XENABLEACCESSCONTROL
 #define XEqualRegion XEQUALREGION
 #define XEventsQueued XEVENTSQUEUED
+#define XExtendedMaxRequestSize XEXTENDEDMAXREQUESTSIZE
 #define XExtentsOfFontSet XEXTENTSOFFONTSET
+#define XFetchBuffer XFETCHBUFFER
 #define XFetchName XFETCHNAME
 #define XFillArc XFILLARC
 #define XFillArcs XFILLARCS
@@ -129,6 +136,7 @@
 #define XFreeModifiermap XFREEMODIFIERMAP
 #define XFreePixmap XFREEPIXMAP
 #define XFreeStringList XFREESTRINGLIST
+#define XGContextFromGC XGCONTEXTFROMGC
 #define XGetAtomName XGETATOMNAME
 #define XGetCommand XGETCOMMAND
 #define XGetDefault XGETDEFAULT
@@ -145,12 +153,14 @@
 #define XGetImage XGETIMAGE
 #define XGetInputFocus XGETINPUTFOCUS
 #define XGetKeyboardControl XGETKEYBOARDCONTROL
+#define XGetKeyboardMapping XGETKEYBOARDMAPPING
 #define XGetModifierMapping XGETMODIFIERMAPPING
 #define XGetMotionEvents XGETMOTIONEVENTS
 #define XGetNormalHints XGETNORMALHINTS
 #define XGetRGBColormaps XGETRGBCOLORMAPS
 #define XGetScreenSaver XGETSCREENSAVER
 #define XGetSelectionOwner XGETSELECTIONOWNER
+#define XGetStandardColormap XGETSTANDARDCOLORMAP
 #define XGetSubImage XGETSUBIMAGE
 #define XGetTextProperty XGETTEXTPROPERTY
 #define XGetVisualInfo XGETVISUALINFO
@@ -169,11 +179,13 @@
 #define XIfEvent XIFEVENT
 #define XInstallColormap XINSTALLCOLORMAP
 #define XInternAtom XINTERNATOM
+#define XInternAtoms XINTERNATOMS
 #define XIntersectRegion XINTERSECTREGION
 #define XKeycodeToKeysym XKEYCODETOKEYSYM
 #define XKeysymToKeycode XKEYSYMTOKEYCODE
 #define XKeysymToString XKEYSYMTOSTRING
 #define XKillClient XKILLCLIENT
+#define XListDepths XLISTDEPTHS
 #define XListFonts XLISTFONTS
 #define XListFontsWithInfo XLISTFONTSWITHINFO
 #define XListHosts XLISTHOSTS
@@ -192,9 +204,11 @@
 #define XMapWindow XMAPWINDOW
 #define XMatchVisualInfo XMATCHVISUALINFO
 #define XMaxRequestSize XMAXREQUESTSIZE
+#define XMissingExtension XMISSINGEXTENSION
 #define XMoveResizeWindow XMOVERESIZEWINDOW
 #define XMoveWindow XMOVEWINDOW
 #define XNextEvent XNEXTEVENT
+#define XNoOp XNOOP
 #define XOffsetRegion XOFFSETREGION
 #define XOpenDevice XOPENDEVICE
 #define XOpenDisplay XOPENDISPLAY
@@ -208,6 +222,8 @@
 #define XPolygonRegion XPOLYGONREGION
 #define XPutBackEvent XPUTBACKEVENT
 #define XPutImage XPUTIMAGE
+#define XQueryBestCursor XQUERYBESTCURSOR
+#define XQueryBestStipple XQUERYBESTSTIPPLE
 #define XQueryColor XQUERYCOLOR
 #define XQueryColors XQUERYCOLORS
 #define XQueryDeviceState XQUERYDEVICESTATE
@@ -273,8 +289,7 @@
 #define XSetTSOrigin XSETTSORIGIN
 #define XSetTile XSETTILE
 #define XSetTransientForHint XSETTRANSIENTFORHINT
-#define XSetWindowBorder XSETWINDOWBORDER
-#define XSetWindowBorderWidth XSETWINDOWBORDERWIDTH
+#define XSetWMClientMachine XSETWMCLIENTMACHINE
 #define XSetWMColormapWindows XSETWMCOLORMAPWINDOWS
 #define XSetWMHints XSETWMHINTS
 #define XSetWMIconName XSETWMICONNAME
@@ -282,13 +297,27 @@
 #define XSetWMNormalHints XSETWMNORMALHINTS
 #define XSetWMProperties XSETWMPROPERTIES
 #define XSetWMProtocols XSETWMPROTOCOLS
+#define XSetWMSizeHints XSETWMSIZEHINTS
 #define XSetWindowBackground XSETWINDOWBACKGROUND
 #define XSetWindowBackgroundPixmap XSETWINDOWBACKGROUNDPIXMAP
+#define XSetWindowBorder XSETWINDOWBORDER
+#define XSetWindowBorderPixmap XSETWINDOWBORDERPIXMAP
+#define XSetWindowBorderWidth XSETWINDOWBORDERWIDTH
 #define XSetWindowColormap XSETWINDOWCOLORMAP
 #define XShapeCombineMask XSHAPECOMBINEMASK
 #define XShapeCombineRectangles XSHAPECOMBINERECTANGLES
 #define XShapeGetRectangles XSHAPEGETRECTANGLES
+#define XShapeQueryExtension XSHAPEQUERYEXTENSION
+#define XShmAttach XSHMATTACH
+#define XShmCreateImage XSHMCREATEIMAGE
+#define XShmCreatePixmap XSHMCREATEPIXMAP
+#define XShmDetach XSHMDETACH
+#define XShmGetEventBase XSHMGETEVENTBASE
+#define XShmPutImage XSHMPUTIMAGE
+#define XShmQueryExtension XSHMQUERYEXTENSION
+#define XShmQueryVersion XSHMQUERYVERSION
 #define XShrinkRegion XSHRINKREGION
+#define XStoreBuffer XSTOREBUFFER
 #define XStoreBytes XSTOREBYTES
 #define XStoreColor XSTORECOLOR
 #define XStoreColors XSTORECOLORS
@@ -318,24 +347,33 @@
 #define XUnsetICFocus XUNSETICFOCUS
 #define XVaCreateNestedList XVACREATENESTEDLIST
 #define XVisualIDFromVisual XVISUALIDFROMVISUAL
-#define XWhitePixelOfScreen XWHITEPIXELOFSCREEN
 #define XWMGeometry XWMGEOMETRY
 #define XWarpPointer XWARPPOINTER
 #define XWhitePixel XWHITEPIXEL
+#define XWhitePixelOfScreen XWHITEPIXELOFSCREEN
 #define XWidthOfScreen XWIDTHOFSCREEN
 #define XWindowEvent XWINDOWEVENT
 #define XWithdrawWindow XWITHDRAWWINDOW
 #define XXorRegion XXORREGION
+#define XcmsQueryColor XCMSQUERYCOLOR
+#define XextAddDisplay XEXTADDDISPLAY
+#define XextFindDisplay XEXTFINDDISPLAY
+#define XextRemoveDisplay XEXTREMOVEDISPLAY
 #define XmActivateProtocol XMACTIVATEPROTOCOL
 #define XmAddProtocolCallback XMADDPROTOCOLCALLBACK
 #define XmAddProtocols XMADDPROTOCOLS
 #define XmChangeColor XMCHANGECOLOR
 #define XmClipboardCopy XMCLIPBOARDCOPY
+#define XmClipboardCopyByName XMCLIPBOARDCOPYBYNAME
 #define XmClipboardEndCopy XMCLIPBOARDENDCOPY
+#define XmClipboardEndRetrieve XMCLIPBOARDENDRETRIEVE
+#define XmClipboardInquireCount XMCLIPBOARDINQUIRECOUNT
+#define XmClipboardInquireFormat XMCLIPBOARDINQUIREFORMAT
 #define XmClipboardInquireLength XMCLIPBOARDINQUIRELENGTH
 #define XmClipboardLock XMCLIPBOARDLOCK
 #define XmClipboardRetrieve XMCLIPBOARDRETRIEVE
 #define XmClipboardStartCopy XMCLIPBOARDSTARTCOPY
+#define XmClipboardStartRetrieve XMCLIPBOARDSTARTRETRIEVE
 #define XmClipboardUnlock XMCLIPBOARDUNLOCK
 #define XmCreateArrowButton XMCREATEARROWBUTTON
 #define XmCreateArrowButtonGadget XMCREATEARROWBUTTONGADGET
@@ -544,6 +582,12 @@
 #define XmbTextExtents XMBTEXTEXTENTS
 #define XmbTextListToTextProperty XMBTEXTLISTTOTEXTPROPERTY
 #define XmbTextPropertyToTextList XMBTEXTPROPERTYTOTEXTLIST
+#define XmbufCreateBuffers XMBUFCREATEBUFFERS
+#define XmbufDestroyBuffers XMBUFDESTROYBUFFERS
+#define XmbufDisplayBuffers XMBUFDISPLAYBUFFERS
+#define XmbufQueryExtension XMBUFQUERYEXTENSION
+#define Xmemory_free XMEMORY_FREE
+#define Xmemory_malloc XMEMORY_MALLOC
 #define XmuClientWindow XMUCLIENTWINDOW
 #define XmuCvtStringToBitmap XMUCVTSTRINGTOBITMAP
 #define XmuLookupStandardColormap XMULOOKUPSTANDARDCOLORMAP
@@ -563,6 +607,7 @@
 #define XrmPutStringResource XRMPUTSTRINGRESOURCE
 #define XrmQPutStringResource XRMQPUTSTRINGRESOURCE
 #define XrmQuarkToString XRMQUARKTOSTRING
+#define XrmSetDatabase XRMSETDATABASE
 #define XrmStringToBindingQuarkList XRMSTRINGTOBINDINGQUARKLIST
 #define XrmStringToQuark XRMSTRINGTOQUARK
 #define XrmStringToQuark XRMSTRINGTOQUARK
@@ -650,6 +695,7 @@
 #define XtParseTranslationTable XTPARSETRANSLATIONTABLE
 #define XtPopdown XTPOPDOWN
 #define XtPopup XTPOPUP
+#define XtPopupSpringLoaded XTPOPUPSPRINGLOADED
 #define XtQueryGeometry XTQUERYGEOMETRY
 #define XtRealizeWidget XTREALIZEWIDGET
 #define XtRealloc XTREALLOC
@@ -698,9 +744,19 @@
 #define XwcTextExtents XWCTEXTEXTENTS
 #define XwcTextListToTextProperty XWCTEXTLISTTOTEXTPROPERTY
 #define XwcTextPropertyToTextList XWCTEXTPROPERTYTOTEXTLIST
+#define _XAllocTemp _XALLOCTEMP
+#define _XDeqAsyncHandler _XDEQASYNCHANDLER
+#define _XEatData _XEATDATA
+#define _XFlush _XFLUSH
+#define _XFreeTemp _XFREETEMP
+#define _XGetAsyncReply _XGETASYNCREPLY 
 #define _XInitImageFuncPtrs _XINITIMAGEFUNCPTRS
+#define _XRead _XREAD
 #define _XRegisterFilterByType _XREGISTERFILTERBYTYPE 
+#define _XReply _XREPLY
+#define _XSend _XSEND
 #define _XUnregisterFilter _XUNREGISTERFILTER
+#define _XVIDtoVisual _XVIDTOVISUAL
 #define _XmBottomShadowColorDefault _XMBOTTOMSHADOWCOLORDEFAULT
 #define _XmClearBorder _XMCLEARBORDER
 #define _XmConfigureObject _XMCONFIGUREOBJECT
@@ -743,14 +799,64 @@
 #define _XtInheritTranslations _XTINHERITTRANSLATIONS
 #define applicationShellWidgetClass APPLICATIONSHELLWIDGETCLASS
 #define compositeWidgetClass COMPOSITEWIDGETCLASS
+#define exe$getspi EXE$GETSPI
+#define lbr$close LBR$CLOSE
+#define lbr$get_header LBR$GET_HEADER
+#define lbr$get_index LBR$GET_INDEX
+#define lbr$get_record LBR$GET_RECORD
+#define lbr$ini_control LBR$INI_CONTROL
+#define lbr$lookup_key LBR$LOOKUP_KEY
+#define lbr$open LBR$OPEN
+#define lib$add_times LIB$ADD_TIMES
+#define lib$addx LIB$ADDX
+#define lib$create_dir LIB$CREATE_DIR
+#define lib$create_vm_zone LIB$CREATE_VM_ZONE
+#define lib$cvt_from_internal_time LIB$CVT_FROM_INTERNAL_TIME
+#define lib$cvt_htb LIB$CVT_HTB
+#define lib$cvt_vectim LIB$CVT_VECTIM
+#define lib$day LIB$DAY
+#define lib$day_of_week LIB$DAY_OF_WEEK
+#define lib$delete_symbol LIB$DELETE_SYMBOL
+#define lib$delete_vm_zone LIB$DELETE_VM_ZONE
+#define lib$disable_ctrl LIB$DISABLE_CTRL
 #define lib$ediv LIB$EDIV
+#define lib$emul LIB$EMUL
+#define lib$enable_ctrl LIB$ENABLE_CTRL
+#define lib$find_vm_zone LIB$FIND_VM_ZONE
+#define lib$format_date_time LIB$FORMAT_DATE_TIME
+#define lib$free_timer LIB$FREE_TIMER
+#define lib$free_vm LIB$FREE_VM
+#define lib$get_ef LIB$GET_EF
+#define lib$get_foreign LIB$GET_FOREIGN
+#define lib$get_users_language LIB$GET_USERS_LANGUAGE
+#define lib$get_vm LIB$GET_VM
+#define lib$get_symbol LIB$GET_SYMBOL
+#define lib$getdvi LIB$GETDVI
+#define lib$init_date_time_context LIB$INIT_DATE_TIME_CONTEXT
+#define lib$init_timer LIB$INIT_TIMER
 #define lib$find_file LIB$FIND_FILE
 #define lib$find_file_end LIB$FIND_FILE_END
+#define lib$find_image_symbol LIB$FIND_IMAGE_SYMBOL
+#define lib$mult_delta_time LIB$MULT_DELTA_TIME
+#define lib$rename_file LIB$RENAME_FILE
+#define lib$reset_vm_zone LIB$RESET_VM_ZONE
 #define lib$set_symbol LIB$SET_SYMBOL
 #define lib$sfree1_dd LIB$SFREE1_DD
+#define lib$show_vm LIB$SHOW_VM
+#define lib$show_vm_zone LIB$SHOW_VM_ZONE
 #define lib$spawn LIB$SPAWN
+#define lib$stat_timer LIB$STAT_TIMER
 #define lib$subx LIB$SUBX
+#define lib$sub_times LIB$SUB_TIMES
 #define lib$wait LIB$WAIT
+#define mail$send_add_address MAIL$SEND_ADD_ADDRESS
+#define mail$send_add_attribute MAIL$SEND_ADD_ATTRIBUTE
+#define mail$send_add_bodypart MAIL$SEND_ADD_BODYPART
+#define mail$send_begin MAIL$SEND_BEGIN
+#define mail$send_end MAIL$SEND_END
+#define mail$send_message MAIL$SEND_MESSAGE
+#define ncs$convert NCS$CONVERT
+#define ncs$get_cf NCS$GET_CF
 #define overrideShellWidgetClass OVERRIDESHELLWIDGETCLASS
 #define pthread_attr_create PTHREAD_ATTR_CREATE
 #define pthread_attr_delete PTHREAD_ATTR_DELETE
@@ -772,7 +878,9 @@
 #define pthread_attr_setsched PTHREAD_ATTR_SETSCHED
 #define pthread_attr_setschedparam PTHREAD_ATTR_SETSCHEDPARAM
 #define pthread_attr_setschedpolicy PTHREAD_ATTR_SETSCHEDPOLICY
-#define pthread_attr_setscope PTHREAD_ATTR_SETSCOPE
+#ifndef pthread_attr_setscope
+# define pthread_attr_setscope PTHREAD_ATTR_SETSCOPE
+#endif
 #define pthread_attr_setstacksize PTHREAD_ATTR_SETSTACKSIZE
 #define pthread_cancel PTHREAD_CANCEL
 #define pthread_cancel_e PTHREAD_CANCEL_E
@@ -841,24 +949,95 @@
 #define pthread_yield PTHREAD_YIELD
 #define pthread_yield_np PTHREAD_YIELD_NP
 #define shellWidgetClass SHELLWIDGETCLASS
+#define shmat SHMAT
+#define shmctl SHMCTL
+#define shmdt SHMDT
+#define shmget SHMGET
+#define sys$add_ident SYS$ADD_IDENT
+#define sys$asctoid SYS$ASCTOID
 #define sys$assign SYS$ASSIGN
 #define sys$bintim SYS$BINTIM
+#define sys$cancel SYS$CANCEL
+#define sys$cantim SYS$CANTIM
+#define sys$check_access SYS$CHECK_ACCESS
+#define sys$close SYS$CLOSE
+#define sys$connect SYS$CONNECT
+#define sys$create SYS$CREATE
+#define sys$create_user_profile SYS$CREATE_USER_PROFILE
 #define sys$crembx SYS$CREMBX
+#define sys$creprc SYS$CREPRC
+#define sys$crmpsc SYS$CRMPSC
 #define sys$dassgn SYS$DASSGN
+#define sys$dclast SYS$DCLAST
 #define sys$dclexh SYS$DCLEXH
+#define sys$delprc SYS$DELPRC
+#define sys$deq SYS$DEQ
+#define sys$dgblsc SYS$DGBLSC
+#define sys$display SYS$DISPLAY
+#define sys$enq SYS$ENQ
+#define sys$enqw SYS$ENQW
+#define sys$erase SYS$ERASE
+#define sys$fao SYS$FAO
+#define sys$faol SYS$FAOL
+#define sys$find_held SYS$FIND_HELD
+#define sys$finish_rdb SYS$FINISH_RDB
+#define sys$flush SYS$FLUSH
+#define sys$forcex SYS$FORCEX
+#define sys$get SYS$GET
+#define sys$get_security SYS$GET_SECURITY
 #define sys$getdviw SYS$GETDVIW
+#define sys$getjpi SYS$GETJPI
+#define sys$getjpiw SYS$GETJPIW
+#define sys$getlkiw SYS$GETLKIW
+#define sys$getmsg SYS$GETMSG
+#define sys$getsyi SYS$GETSYI
 #define sys$getsyiw SYS$GETSYIW
 #define sys$gettim SYS$GETTIM
+#define sys$getuai SYS$GETUAI
+#define sys$grantid SYS$GRANTID
+#define sys$hash_password SYS$HASH_PASSWORD
+#define sys$hiber SYS$HIBER
+#define sys$mgblsc SYS$MGBLSC
+#define sys$numtim SYS$NUMTIM
+#define sys$open SYS$OPEN
+#define sys$parse SYS$PARSE
+#define sys$parse_acl SYS$PARSE_ACL
+#define sys$parse_acl SYS$PARSE_ACL
+#define sys$persona_assume SYS$PERSONA_ASSUME
+#define sys$persona_create SYS$PERSONA_CREATE
+#define sys$persona_delete SYS$PERSONA_DELETE
+#define sys$process_scan SYS$PROCESS_SCAN
+#define sys$put SYS$PUT
 #define sys$qio SYS$QIO
 #define sys$qiow SYS$QIOW
+#define sys$read SYS$READ
+#define sys$resched SYS$RESCHED
+#define sys$rewind SYS$REWIND
+#define sys$search SYS$SEARCH
+#define sys$set_security SYS$SET_SECURITY
+#define sys$setast SYS$SETAST
 #define sys$setef SYS$SETEF
+#define sys$setimr SYS$SETIMR
+#define sys$setpri SYS$SETPRI
+#define sys$setprn SYS$SETPRN
+#define sys$setprv SYS$SETPRV
+#define sys$setswm SYS$SETSWM
+#define sys$setuai SYS$SETUAI
+#define sys$sndopr SYS$SNDOPR
 #define sys$synch SYS$SYNCH
+#define sys$trnlnm SYS$TRNLNM
+#define sys$update SYS$UPDATE
+#define sys$wake SYS$WAKE
+#define sys$write SYS$WRITE
 #define topLevelShellClassRec TOPLEVELSHELLCLASSREC
 #define topLevelShellWidgetClass TOPLEVELSHELLWIDGETCLASS
 #define transientShellWidgetClass TRANSIENTSHELLWIDGETCLASS
 #define vendorShellClassRec VENDORSHELLCLASSREC
 #define vendorShellWidgetClass VENDORSHELLWIDGETCLASS
 #define wmShellWidgetClass WMSHELLWIDGETCLASS
+#define x$soft_ast_lib_lock X$SOFT_AST_LIB_LOCK
+#define x$soft_ast_lock_depth X$SOFT_AST_LOCK_DEPTH
+#define x$soft_reenable_asts X$SOFT_REENABLE_ASTS
 #define xmArrowButtonWidgetClass XMARROWBUTTONWIDGETCLASS
 #define xmBulletinBoardWidgetClass XMBULLETINBOARDWIDGETCLASS
 #define xmCascadeButtonClassRec XMCASCADEBUTTONCLASSREC
@@ -897,6 +1076,13 @@
 #define xmToggleButtonGadgetClass XMTOGGLEBUTTONGADGETCLASS
 #define xmToggleButtonWidgetClass XMTOGGLEBUTTONWIDGETCLASS
 
+#define SetReqLen(req,n,badlen) \
+    if ((req->length + n) > (unsigned)65535) { \
+	    n = badlen; \
+	    req->length += n; \
+    } else \
+	req->length += n
+
 #ifdef __cplusplus
 extern "C" {
 #endif
