@@ -409,7 +409,7 @@ struct hostent {
 #define CLASS class
 #endif
 
-#if (!defined( AFS ) && !defined( SIA ) && defined( HAVE_SHADOW ) && !defined( OSF1_ENH_SEC ) && !defined( HP_PASSWDETC ) && !defined( VMS ) && !defined( PAM ))
+#if (!defined( AFS ) && !defined( SIA ) && defined( HAVE_SHADOW ) && !defined( OSF1_ENH_SEC ) && !defined( HP_PASSWDETC ) && !defined( VMS ) && !defined( PAM ) && !defined( PASSWD_HELPER_PROGRAM ))
 #define FALLBACK_XLOCKRC
 #endif
 
